Stan Math Library: stan/math/prim/mat/fun/trace_quad_form.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

trace_quad_form.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_TRACE_QUAD_FORM_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_TRACE_QUAD_FORM_HPP
3
4 #include <boost/utility/enable_if.hpp>
5 #include <boost/type_traits.hpp>
6 #include <stan/math/prim/mat/fun/Eigen.hpp>
7 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
8 #include <stan/math/prim/mat/err/check_square.hpp>
9
10 namespace stan {
11 namespace math {
15 template<int RA, int CA, int RB, int CB>
16 inline double
17 trace_quad_form(const Eigen::Matrix<double, RA, CA> &A,
18 const Eigen::Matrix<double, RB, CB> &B) {
19 stan::math::check_square("trace_quad_form", "A", A);
20 stan::math::check_multiplicable("trace_quad_form",
21 "A", A,
22 "B", B);
23
24 return (B.transpose()*A*B).trace();
25 }
26
27 }
28 }
29
30 #endif
31
check_multiplicable.hpp
stan::math::trace_quad_form
fvar< T > trace_quad_form(const Eigen::Matrix< fvar< T >, RA, CA > &A, const Eigen::Matrix< fvar< T >, RB, CB > &B)
Definition: trace_quad_form.hpp:18
stan
Definition: log_sum_exp.hpp:8
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
Eigen.hpp
stan::math::trace
T trace(const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
Returns the trace of the specified matrix.
Definition: trace.hpp:20
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.